@@ -1657,6 +1657,11 @@ static void load_column(const XmlNode *node, gpointer user)
 	gint		index;
 	DPContent	cid;
 
+	union {
+		GtkJustification	justification;
+		gint			integer;
+	} jtmp;
+
 	if(!xml_node_has_name(node, "DPColumn"))	/* Not actually a column? */
 		return;
 
@@ -1679,7 +1684,8 @@ static void load_column(const XmlNode *node, gpointer user)
 		}
 		if((data = xml_tree_search(node, "DPExtra")) != NULL)
 			load_extra(data, colfmt->content, &colfmt->extra);
-		xml_get_integer(node, "justification", (gint *) &colfmt->just);
+		xml_get_integer(node, "justification", &jtmp.integer);
+		colfmt->just = jtmp.justification;
 		xml_get_integer(node, "width", &colfmt->width);
 	}
 	else
