@@ -302,8 +302,13 @@ static void load_path(const XmlNode *data, gpointer user)
 static void load_hideinfo(MainInfo *min, const XmlNode *node)
 {
 	gint	tmp;
+	union {
+		HMode	hmode;
+		gint	integer;
+	} htmp;
 
-	xml_get_integer(node, "mode", (gint *) &min->cfg.path.hideinfo.mode);
+	xml_get_integer(node, "mode", &htmp.integer);
+	min->cfg.path.hideinfo.mode = htmp.hmode;
 	xml_get_text_copy(node, "re", min->cfg.path.hideinfo.hide_re_src, sizeof min->cfg.path.hideinfo.hide_re_src);
 	if(xml_get_boolean(node, "re_nocase", &tmp))
 		min->cfg.path.hideinfo.no_case = tmp;
