@@ -26,6 +26,7 @@
 #include "iconutil.h"
 #include "strutil.h"
 #include "fileutil.h"
+#include "miscutil.h"
 #include "xmlutil.h"
 #include "guiutil.h"
 #include "style_dialog.h"
@@ -391,8 +392,7 @@ static void evt_aprop_selected(GtkWidget *wid, gint row, gint column, GdkEventBu
 		gtk_widget_set_sensitive(page->dpaction.aname, TRUE);
 		gtk_entry_set_text(GTK_ENTRY(page->dpaction.acmdseq), stl_style_property_get_action(page->curr_style, prop));
 		/* Force execution of cmdseq_changed() before we set curr_prop & curr_arow. */
-		while(gtk_events_pending())
-			gtk_main_iteration();
+		gui_events_flush();
 		gtk_widget_set_sensitive(page->dpaction.acmdseq, TRUE);
 		gtk_widget_set_sensitive(page->dpaction.acmdpick, TRUE);
 		page->curr_prop = prop;
