@@ -148,8 +148,8 @@ static gboolean chown_dir(MainInfo *min, const gchar *name, uid_t owner, gid_t g
 static gint cho_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, gpointer user)
 {
 	ChoInfo		*cho = user;
-	uid_t		owner;
-	gid_t		group;
+	uid_t		owner = 0;
+	gid_t		group = 0;
 	gboolean	ok;
 
 	if(!fut_cd(src->dir.path, NULL, 0))
