@@ -56,6 +56,10 @@ typedef struct {
 	GtkWidget	*map_to;
 	GtkWidget	*map_remove;
 
+	/* Case-conversion mode. */
+	GtkWidget	*case_vbox;
+	GtkWidget	*case_lower;
+
 	MainInfo	*min;
 	DirPane		*src;
 	gint		page;
@@ -64,6 +68,50 @@ typedef struct {
 
 /* ----------------------------------------------------------------------------------------- */
 
+static gint do_rename(MainInfo *min, DirPane *dp, GSList **iter, GString *nn, gint *err)
+{
+	if(strcmp(DP_SEL_NAME(*iter), nn->str) != 0)
+	{
+		OvwRes	ores;
+
+		ores = ovw_overwrite_file(min, nn->str, NULL);
+		if(ores == OVW_SKIP)
+			return 0;
+		else if(ores == OVW_CANCEL)
+		{
+			*iter = NULL;
+			return -1;
+		}
+		else if(ores == OVW_PROCEED_FILE)
+		{
+			if(!del_delete_file(min, nn->str))
+			{
+				*iter = NULL;
+				return -1;
+			}
+		}
+		else if(ores == OVW_PROCEED_DIR)
+		{
+			if(!del_delete_dir(min, nn->str, FALSE))
+			{
+				*iter = NULL;
+				return -1;
+			}
+		}
+		if(rename(DP_SEL_NAME(*iter), nn->str) != 0)
+		{
+			*err = errno;
+			dp_rescan_post_cmd(dp);
+			err_set(min, *err, CMD_ID, DP_SEL_NAME(*iter));
+		}
+		else
+			dp_unselect(dp, DP_SEL_INDEX(dp, *iter));
+	}
+	return errno;
+}
+
+/* ----------------------------------------------------------------------------------------- */
+
 static gint rename_simple(RenREInfo *ri)
 {
 	const gchar	*from, *to, *ptr, *base;
@@ -104,34 +152,9 @@ static gint rename_simple(RenREInfo *ri)
 				g_string_append_c(nn, *base++);
 		}
 		g_string_append(nn, base);
-		if((strcmp(DP_SEL_NAME(iter), nn->str) != 0) && (strchr(nn->str, G_DIR_SEPARATOR) == NULL))
-		{
-			OvwRes	ores;
-
-			ores = ovw_overwrite_file(ri->min, nn->str, NULL);
-			if(ores == OVW_SKIP)
-				continue;
-			else if(ores == OVW_CANCEL)
-				break;
-			else if(ores == OVW_PROCEED_FILE)
-			{
-				if(!del_delete_file(ri->min, nn->str))
-					break;
-			}
-			else if(ores == OVW_PROCEED_DIR)
-			{
-				if(!del_delete_dir(ri->min, nn->str, FALSE))
-					break;
-			}
-			if(rename(DP_SEL_NAME(iter), nn->str))
-			{
-				err = errno;
-				dp_rescan_post_cmd(ri->src);
-				err_set(ri->min, err, CMD_ID, DP_SEL_NAME(iter));
-			}
-			else
-				dp_unselect(ri->src, DP_SEL_INDEX(ri->src, iter));
-		}
+		if(strchr(nn->str, G_DIR_SEPARATOR) != NULL)
+			continue;
+		do_rename(ri->min, ri->src, &iter, nn, &err);
 	}
 	g_string_free(nn, TRUE);
 	ovw_overwrite_end(ri->min);
@@ -204,37 +227,8 @@ static gint rename_regexp(RenREInfo *ri)
 		{
 			if(regexec(&fromre, DP_SEL_NAME(iter), sizeof match / sizeof match[0], match, 0) == 0)
 			{
-				if(interpolate(nn, to, DP_SEL_NAME(iter), match))
-				{
-					if((strcmp(DP_SEL_NAME(iter), nn->str) != 0) && (strchr(nn->str, G_DIR_SEPARATOR) == NULL))
-					{
-						OvwRes	ores;
-
-						ores = ovw_overwrite_file(ri->min, nn->str, NULL);
-						if(ores == OVW_SKIP)
-							continue;
-						else if(ores == OVW_CANCEL)
-							break;
-						else if(ores == OVW_PROCEED_FILE)
-						{
-							if(!del_delete_file(ri->min, nn->str))
-								break;
-						}
-						else if(ores == OVW_PROCEED_DIR)
-						{
-							if(!del_delete_dir(ri->min, nn->str, FALSE))
-								break;
-						}
-						if(rename(DP_SEL_NAME(iter), nn->str))
-						{
-							err = errno;
-							dp_rescan_post_cmd(ri->src);
-							err_set(ri->min, err, CMD_ID, DP_SEL_NAME(iter));
-						}
-						else
-							dp_unselect(ri->src, DP_SEL_INDEX(ri->src, iter));
-					}
-				}
+				if(interpolate(nn, to, DP_SEL_NAME(iter), match) && strchr(nn->str, G_DIR_SEPARATOR) == NULL)
+					do_rename(ri->min, ri->src, &iter, nn, &err);
 			}
 		}
 		g_string_free(nn, TRUE);
@@ -298,37 +292,40 @@ static int rename_map(RenREInfo *ri)
 			else
 				i++;
 		}
-		if(strcmp(DP_SEL_NAME(iter), nn->str) != 0)
-		{
-			OvwRes	ores;
-
-			ores = ovw_overwrite_file(ri->min, nn->str, NULL);
-			if(ores == OVW_SKIP)
-				continue;
-			else if(ores == OVW_CANCEL)
-				break;
-			else if(ores == OVW_PROCEED_FILE)
-			{
-				if(!del_delete_file(ri->min, nn->str))
-					break;
-			}
-			else if(ores == OVW_PROCEED_DIR)
-			{
-				if(!del_delete_dir(ri->min, nn->str, FALSE))
-					break;
-			}
-			if(rename(DP_SEL_NAME(iter), nn->str) != 0)
-			{
-				err = errno;
-				dp_rescan_post_cmd(ri->src);
-				err_set(ri->min, err, CMD_ID, DP_SEL_NAME(iter));
-			}
-			else
-				dp_unselect(ri->src, DP_SEL_INDEX(ri->src, iter));
-		}
+		do_rename(ri->min, ri->src, &iter, nn, &err);
 	}
 	g_string_free(nn, TRUE);
 	ovw_overwrite_end(ri->min);
+
+	return err;
+}
+
+/* ----------------------------------------------------------------------------------------- */
+
+static int rename_case(RenREInfo *ri)
+{
+	gboolean	lower = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ri->case_lower));
+	GString		*nn;
+	GSList		*iter;
+	gint		err = 0;
+
+	ovw_overwrite_begin(ri->min, _("\"%s\" Already Exists - Proceed With Rename?"), 0U);
+	nn = g_string_new("");
+	for(iter = ri->selection; iter != NULL; iter = g_slist_next(iter))
+	{
+		/* Step 1: set the dynamic string to the input filename. */
+		g_string_assign(nn, DP_SEL_NAME(iter));
+		/* Step 2: perform case conversion. */
+		if(lower)
+			g_string_down(nn);
+		else
+			g_string_up(nn);
+		/* Step 3: if resulting name is different, rename on disk. */
+		do_rename(ri->min, ri->src, &iter, nn, &err);
+	}
+	g_string_free(nn, TRUE);
+	ovw_overwrite_end(ri->min);
+
 	return err;
 }
 
@@ -344,7 +341,7 @@ static void evt_nbook_switchpage(GtkWidget *wid, GtkNotebookPage *page, gint pag
 
 gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	GtkWidget		*label, *table;
+	GtkWidget		*label, *table, *wid;
 	static RenREInfo	ri = { NULL };
 
 	ri.min	= min;
@@ -427,9 +424,19 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		ri.map_remove = gtk_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.map_remove, 1, 2, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
 		gtk_box_pack_start(GTK_BOX(ri.map_vbox), table, FALSE, FALSE, 0);
-
 		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.map_vbox, gtk_label_new(_("Map")));
 
+		/* Build the 'Case' mode's GUI. */
+		ri.case_vbox = gtk_vbox_new(FALSE, 0);
+		label = gtk_label_new(_("Convert all characters in filename to either\nall-lower or all-upper case."));
+		gtk_box_pack_start(GTK_BOX(ri.case_vbox), label, FALSE, FALSE, 0);
+		ri.case_lower = gtk_radio_button_new_with_label(NULL, _("Lower Case?"));
+		gtk_box_pack_start(GTK_BOX(ri.case_vbox), ri.case_lower, FALSE, FALSE, 0);
+		wid = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(ri.case_lower)), _("Upper Case?"));
+		gtk_box_pack_start(GTK_BOX(ri.case_vbox), wid, FALSE, FALSE, 0);
+		gtk_widget_show_all(ri.map_vbox);
+		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.case_vbox, gtk_label_new(_("Case")));
+
 		ri.dlg = dlg_dialog_sync_new(ri.nbook, _("RenameRE"), NULL);
 
 		ri.page = 0;
@@ -449,8 +456,10 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 				err = rename_simple(&ri);
 			else if(ri.page == 1)
 				err = rename_regexp(&ri);
-			else
+			else if(ri.page == 2)
 				err = rename_map(&ri);
+			else
+				err = rename_case(&ri);
 			fut_cd(old, NULL, 0U);
 		}
 		else
