@@ -36,6 +36,8 @@
 #include "dpformat.h"
 #include "events.h"
 #include "fileutil.h"
+#include "guiutil.h"
+#include "miscutil.h"
 #include "strutil.h"
 #include "types.h"
 
@@ -126,8 +128,7 @@ gint cmd_selectrow(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		action = car_keyword_get_enum(ca, "action", 0, "select", "unselect", "toggle", NULL);
 		afunc = (action == 0) ? dp_select : (action == 1) ? dp_unselect : dp_toggle;
 		afunc(src, row);
-		while(gtk_events_pending())
-			gtk_main_iteration();
+		gui_events_flush();
 	}
 	return 1;
 }
@@ -446,7 +447,7 @@ static void selparam_get_value_pointers(guint **ptr, SelParam *sp)
 	ptr[0] = &sp->set;
 	ptr[1] = &sp->type;
 	ptr[2] = &sp->action;
-	ptr[3] = (guint *) &sp->content;
+	ptr[3] = &sp->content;
 }
 
 static void selparam_read_menus(guint **ptr, GtkWidget *opt_menu[])
@@ -502,7 +503,7 @@ gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		mptr[0] = &sp.basic.set;
 		mptr[1] = &sp.basic.type;
 		mptr[2] = &sp.basic.action;
-		mptr[3] = (guint *) &sp.basic.content;
+		mptr[3] = &sp.basic.content;
 
 		vbox = gtk_vbox_new(FALSE, 0);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 2);
