@@ -95,7 +95,7 @@ static void build_name(SplitInfo *spi, DirPane *dst, gchar *buf, gint piece)
 static gint size_split(SplitInfo *spi, DirPane *src, DirPane *dst, DirRow *row)
 {
 	gchar	inname[PATH_MAX], outname[PATH_MAX];
-	gsize	seg_size, to_go, chunk;
+	gsize	seg_size, to_go = 0, chunk;
 	gint	ifd, ofd, piece = 0;
 	OvwRes	ores;
 
