@@ -170,7 +170,7 @@ void cmc_config_base_load(CmdCfg *cmc, const XmlNode *node)
 					xml_get_boolean(node, fld->name, (gboolean *) ((gchar *) cmc->base + fld->offset));
 					break;
 				case CFT_ENUM:
-					xml_get_uinteger(node, fld->name, (gint *) ((gchar *) cmc->base + fld->offset));
+					xml_get_uinteger(node, fld->name, (guint *) ((gchar *) cmc->base + fld->offset));
 					break;
 				case CFT_SIZE:
 					xml_get_uinteger(node, fld->name, (gsize *) ((gchar *) cmc->base + fld->offset));
@@ -348,7 +348,7 @@ void cmc_field_add_size(CmdCfg *cmc, const gchar *name, const gchar *desc, gsize
 		CField	*fld = field_new(CFT_SIZE, name, desc, offset);
 
 		fld->field.size.min = min;
-		fld->field.size.max = max;
+		fld->field.size.max = max + step;
 		fld->field.size.step = step;
 
 		field_add(cmc, fld);
