@@ -216,12 +216,15 @@ gint dlg_dialog_sync_wait(Dialog *dlg)
 {
 	if(dlg != NULL)
 	{
+		int	old_errno = errno;
+
 		gtk_widget_realize(dlg->dlg);
 		gdk_window_set_group(dlg->dlg->window, the_state.group_window);
 		gtk_widget_show(dlg->dlg);
 		gdk_window_raise(dlg->dlg->window);
 		gtk_grab_add(dlg->dlg);
 		gtk_main();
+		errno = old_errno;
 		return dlg->button;
 	}
 	return -1;
