@@ -541,8 +541,7 @@ static void evt_dirpane_select_row(GtkWidget *wid, gint row, gint col, GdkEventB
 		{
 			dp->dbclk_row = row;
 			dp_unselect(dp, row);
-			while(gtk_events_pending())
-				gtk_main_iteration();
+			gui_events_flush();
 			doubleclick(dp);
 			dp->dbclk_row = -1;
 			last_time = ev->time;
