@@ -12,6 +12,7 @@
 
 #include "dirpane.h"
 #include "dialog.h"
+#include "guiutil.h"
 #include "errors.h"
 
 /* ----------------------------------------------------------------------------------------- */
@@ -37,8 +38,7 @@ void err_printf(MainInfo *min, const gchar *fmt, ...)
 	vsnprintf(error_desc, sizeof error_desc, fmt, al);
 	va_end(al);
 	err_show(min);
-	while(gtk_events_pending())		/* This might qualify as a kludge. */
-		gtk_main_iteration();
+	gui_events_flush();
 }
 
 /* 1998-05-30 -	Added special treatment of code == -1; this means that there is no
@@ -78,8 +78,7 @@ void err_show(MainInfo *min)
 	if(error_desc[0] != '\0')
 	{
 		gtk_label_set_text(GTK_LABEL(min->gui->top), error_desc);
-		while(gtk_events_pending())
-			gtk_main_iteration();
+		gui_events_flush();
 		if(min->cfg.errors.dialog)
 			dlg_dialog_async_new_simple(error_desc, "Error", "OK", NULL, NULL);
 		if(min->cfg.errors.beep)
