@@ -14,8 +14,12 @@
 #include "config.h"
 
 #if !(defined __osf__ && defined __alpha__) && !defined __NetBSD__ && !defined __FreeBSD__ && !defined __sgi
+#if !defined __EXTENSIONS__
 #define __EXTENSIONS__
+#endif
+#if !defined _POSIX_C_SOURCE
 #define _POSIX_C_SOURCE	3	/* This is for Solaris. */
+#endif
 #define	POSIX_C_SOURCE	3
 #endif				/* !__osf__ && !__alpha */
 
@@ -24,7 +28,9 @@
 #define	_OSF_SOURCE					/* For MAXNAMLEN on Tru64. */
 #endif
 
+#if !defined _BSD_SOURCE
 #define	_BSD_SOURCE					/* For MAXNAMLEN on Linux. */
+#endif
 
 #include <dirent.h>
 #include <errno.h>
