@@ -9,6 +9,7 @@
 #include "dialog.h"
 #include "dirpane.h"
 #include "fileutil.h"
+#include "guiutil.h"
 #include "strutil.h"
 
 #include "menus.h"
@@ -350,7 +351,6 @@ static void evt_menu_activate(GtkWidget *wid, gpointer user)
 {
 	MainInfo	*min;
 
-/*	fprintf(stderr, "Now in menu activation code, wid=%p, cmdseq=\"%s\"\n", wid, user);*/
 	min = gtk_object_get_user_data(GTK_OBJECT(wid));	
 	csq_execute(min, user);
 }
@@ -358,22 +358,13 @@ static void evt_menu_activate(GtkWidget *wid, gpointer user)
 static void evt_menu_show(GtkWidget *wid, gpointer user)
 {
 	DynMenu	*dm = user;
-/*	GTimer	*tmr;
-
-	printf("Menu \"%s\" becoming visible\n", dm->name);
-	tmr = g_timer_new();
-	g_timer_start(tmr);
-*/	dm->build(gtk_object_get_user_data(GTK_OBJECT(wid)), wid);
-/*	g_timer_stop(tmr);
-	printf("Menu built in %g seconds\n", g_timer_elapsed(tmr, NULL));
-*/
+	dm->build(gtk_object_get_user_data(GTK_OBJECT(wid)), wid);
 }
 
 static void evt_menu_hide(GtkWidget *wid, gpointer user)
 {
 	GList	*iter;
 
-/*	printf("Menu \"%s\" no longer visible, clearing\n", dm->name);*/
 	for(iter = gtk_container_children(GTK_CONTAINER(wid)); iter != NULL; iter = g_list_next(iter))
 		gtk_container_remove(GTK_CONTAINER(wid), iter->data);
 }
@@ -465,14 +456,7 @@ void mnu_menu_disuse(const MenuInfo *mi, const gchar *name)
 
 static gboolean evt_popup_destroy(GtkWidget *wid, GdkEvent *evt, gpointer user)
 {
-/*	fprintf(stderr, "Widget at %p being destroyed\n", wid);
-	printf("Popped-up menu hiding: [");
-*/	while(gtk_events_pending())
-	{
-		gtk_main_iteration();
-/*		putchar('.');*/
-	}
-/*	printf("]\n");*/
+	gui_events_flush();
 
 	return FALSE;
 }
@@ -481,14 +465,7 @@ static void evt_popup_hide(GtkWidget *wid, gpointer user)
 {
 	gboolean	ret;
 
-/*	printf("Popped-up menu hiding: [");*/
-	while(gtk_events_pending())
-	{
-		gtk_main_iteration();
-/*		putchar('.');*/
-	}
-/*	printf("]\n");*/
-/*	gtk_widget_unref(wid);*/
+	gui_events_flush();
 	gtk_signal_emit_by_name(GTK_OBJECT(wid), "destroy_event", NULL, &ret);
 }
 
