@@ -15,4 +15,5 @@ typedef struct {
 
 extern guint32	opt_parse(gint *argc, gchar **argv, OptDesc *desc, gsize num_desc);
 
-extern const gpointer	opt_arg_get(const gchar *name, const OptDesc *desc, gsize num_desc);
+extern gconstpointer	opt_arg_get(const gchar *name, const OptDesc *desc, gsize num_desc);
+
