@@ -16,6 +16,7 @@
 
 #include "fileutil.h"
 #include "dirpane.h"
+#include "guiutil.h"
 #include "miscutil.h"
 #include "sizeutil.h"
 #include "progress.h"
@@ -270,8 +271,7 @@ void pgs_progress_item_begin(MainInfo *min, const gchar *name, off_t size)
 		g_snprintf(buf, sizeof buf, "%s (%s)", name, size_buf);
 		gtk_label_set_text(GTK_LABEL(pgs_info.item), buf);
 	}
-	while(gtk_events_pending())
-		gtk_main_iteration();
+	gui_events_flush();
 }
 
 /* 1998-09-30 -	Indicate progress operating on the most recently registered item. Our
@@ -323,8 +323,7 @@ PgsRes pgs_progress_item_update(MainInfo *min, off_t pos)
 			gtk_progress_bar_update(GTK_PROGRESS_BAR(pgs_info.byte_pgs), (gfloat) (pgs_info.byte_pos + pos) / pgs_info.byte_tot);
 		if(pgs_info.show_item && pgs_info.item_size)
 			gtk_progress_bar_update(GTK_PROGRESS_BAR(pgs_info.item_pgs), (gfloat) pos / pgs_info.item_size);
-		while(gtk_events_pending())
-			gtk_main_iteration();
+		gui_events_flush();
 		if(pgs_info.cancel)
 			return PGS_CANCEL;
 	}
@@ -334,12 +333,8 @@ PgsRes pgs_progress_item_update(MainInfo *min, off_t pos)
 /* 1998-09-30 -	Done with an item. */
 void pgs_progress_item_end(MainInfo *min)
 {
-	gint	old_errno = errno;
-
 	pgs_info.byte_pos += pgs_info.item_size;
 	gtk_progress_bar_update(GTK_PROGRESS_BAR(pgs_info.tot_pgs), (gfloat) pgs_info.tot_pos / pgs_info.tot_num);
-	while(gtk_events_pending())
-		gtk_main_iteration();
-
-	errno = old_errno;
+	gui_events_flush();
 }
+
