@@ -146,6 +146,7 @@ void txv_put_text(GtkWidget *wid, const gchar *text, gint length)
 **		using normal file I/O if mmap() fails, which can happen on certain filesystems.
 ** 1999-03-02 -	New interface, renamed.
 ** 1999-04-06 -	Added the <buf_size> argument, which is used when mmap() isn't.
+** 2008-07-08 -	The <buf_size> argument is now used in mmap mode too, but with a different value.
 */
 gint txv_load_text(GtkWidget *wid, const gchar *name, gboolean use_mmap, gsize buf_size)
 {
@@ -166,7 +167,14 @@ gint txv_load_text(GtkWidget *wid, const gchar *name, gboolean use_mmap, gsize b
 		if(use_mmap && fut_size(name, &size) && (size > 0) &&
 		   (buf = mmap(NULL, size, PROT_READ, MAP_PRIVATE, fd, 0)) != MAP_FAILED)
 		{
-			gtk_text_insert(GTK_TEXT(txi->text), NULL, NULL, NULL, buf, (gint) size);
+			gsize	chunk;
+
+			for(; size > 0; size -= chunk, buf += chunk)
+			{
+				chunk = size > buf_size ? buf_size : size;
+				
+				gtk_text_insert(GTK_TEXT(txi->text), NULL, NULL, NULL, buf, (gint) chunk);
+			}
 			munmap(buf, size);
 		}
 		else
