@@ -9,6 +9,7 @@
 #include <ctype.h>
 #include <stdlib.h>
 
+#include "guiutil.h"
 #include "window.h"
 
 /* ----------------------------------------------------------------------------------------- */
@@ -624,8 +625,7 @@ void win_window_show(GtkWidget *window)
 
 	if((wd != NULL) && wd->pos_use && (wd->x >= 0))
 	{
-		while(gtk_events_pending())
-			gtk_main_iteration();
+		gui_events_flush();
 		gtk_widget_set_uposition(GTK_WIDGET(window), wd->x, wd->y);
 	}
 }
